@@ -107,3 +107,8 @@ class ApiAsana:
         response = requests.put(url=url, headers=self.headers,
                                 data=json.dumps({'data': {"custom_fields": {id_custom_field: value}, }}))
         return response.ok
+
+    def get_story_by_id(self, story_gid, fields: list = []) -> dict:
+        url = f'{self.base_url}/stories/{story_gid}'
+        response = requests.get(url=url, headers=self.headers, params={'opt_fields': fields})
+        return response.json().get('data', {})
